@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2004 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ArgV.h,v 1.23 2008/11/27 05:56:06 lav Exp $ */
+/* $Id: ArgV.h,v 1.25 2010/12/28 11:46:25 lav Exp $ */
 
 #ifndef ARGV_H
 #define ARGV_H
@@ -44,7 +44,7 @@ public:
    void Append(int a) { char buf[32]; sprintf(buf,"%d",a); Append(buf); }
    void Add(const char *a) { Append(a); } // alias
 
-   char *Combine(int start_index=0) const;
+   char *Combine(int start_index=0,int end_index=0) const;
    char *CombineQuoted(int start_index=0) const;
    char *CombineCmd(int i=0) const;
 
