@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -30,12 +30,13 @@ const char *FileFeeder::NextCmd(CmdExec *exec, const char *)
    {
       if(in->error())
       {
-	 fprintf(stderr,"source: %s\n",in->error_text);
+	 fprintf(stderr,"source: %s\n",in->error_text.get());
 	 return 0;
       }
       return "";
    }
-   in->Kill(SIGCONT);
+   if(fg_data==0)
+      fg_data=new FgData(in->GetProcGroup(),true);
    int res=read(fd,buffer,buffer_size-1);
    if(res==0)
    {
@@ -56,3 +57,11 @@ const char *FileFeeder::NextCmd(CmdExec *exec, const char *)
    buffer[res]=0;
    return buffer;
 }
+
+FileFeeder::FileFeeder(FDStream *in)
+ : in(in)
+{
+}
+FileFeeder::~FileFeeder()
+{
+}
