@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1999-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.cc,v 1.109 2010/09/01 09:33:03 lav Exp $ */
+/* $Id: NetAccess.cc,v 1.112 2011/06/16 11:08:42 lav Exp $ */
 
 #include <config.h>
 
@@ -59,6 +59,7 @@ void NetAccess::Init()
    connection_takeover=false;
 
    Reconfig(0);
+   reconnect_interval_current=reconnect_interval;
 }
 
 NetAccess::NetAccess()
@@ -311,15 +312,13 @@ bool NetAccess::ReconnectAllowed()
 
 const char *NetAccess::DelayingMessage()
 {
-   static char buf[80];
    if(connection_limit>0 && connection_limit<=CountConnections())
       return _("Connection limit reached");
    long remains=long(reconnect_interval_current)-(time_t(now)-try_time);
    if(remains<=0)
       return "";
-   sprintf(buf,"%s: %ld",_("Delaying before reconnect"),remains);
    current->TimeoutS(1);
-   return buf;
+   return xstring::format("%s: %ld",_("Delaying before reconnect"),remains);
 }
 
 bool NetAccess::NextTry()
