@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Torrent.cc,v 1.50 2011/04/29 12:05:10 lav Exp $ */
+/* $Id: Torrent.cc,v 1.53 2011/06/28 09:36:27 lav Exp $ */
 
 #include <config.h>
 #include <stdlib.h>
@@ -53,6 +53,54 @@ static ResType torrent_vars[] = {
 };
 static ResDecls torrent_vars_register(torrent_vars);
 
+#if INET6
+#ifdef HAVE_IFADDRS_H
+#include <ifaddrs.h>
+#endif
+static const char *FindGlobalIPv6Address()
+{
+#ifdef HAVE_IFADDRS_H
+   struct ifaddrs *ifaddrs=0;
+   getifaddrs(&ifaddrs);
+   for(struct ifaddrs *ifa=ifaddrs; ifa; ifa=ifa->ifa_next) {
+      if(ifa->ifa_addr && ifa->ifa_addr->sa_family==AF_INET6) {
+	 struct in6_addr *addr=&((struct sockaddr_in6*)ifa->ifa_addr)->sin6_addr;
+	 if(!IN6_IS_ADDR_UNSPECIFIED(addr) && !IN6_IS_ADDR_LOOPBACK(addr)
+	 && !IN6_IS_ADDR_LINKLOCAL(addr) && !IN6_IS_ADDR_SITELOCAL(addr)
+	 && !IN6_IS_ADDR_MULTICAST(addr)) {
+	    char *buf=xstring::tmp_buf(INET6_ADDRSTRLEN);
+	    inet_ntop(AF_INET6, addr, buf, INET6_ADDRSTRLEN);
+	    freeifaddrs(ifaddrs);
+	    return buf;
+	 }
+      }
+   }
+   freeifaddrs(ifaddrs);
+#endif
+   return 0;
+}
+#endif
+
+void Torrent::ClassInit()
+{
+   static bool inited;
+   if(inited)
+      return;
+   inited=true;
+
+#if INET6
+   const char *ipv6=ResMgr::Query("torrent:ipv6",0);
+   if(!*ipv6)
+   {
+      ipv6=FindGlobalIPv6Address();
+      if(ipv6) {
+	 ProtoLog::LogNote(9,"found IPv6 address: %s",ipv6);
+	 ResMgr::Set("torrent:ipv6",0,ipv6);
+      }
+   }
+#endif
+}
+
 xstring Torrent::my_peer_id;
 xstring Torrent::my_key;
 xmap<Torrent*> Torrent::torrents;
@@ -124,7 +172,7 @@ Torrent::Torrent(const char *mf,const char *c,const char *od)
 #endif
    }
    if(!my_peer_id) {
-      my_peer_id.set("-lftp42-");
+      my_peer_id.set("-lftp43-");
       my_peer_id.appendf("%04x",(unsigned)getpid());
       my_peer_id.appendf("%08x",(unsigned)now.UnixTime());
       assert(my_peer_id.length()==PEER_ID_LEN);
@@ -1345,11 +1393,11 @@ void Torrent::Reconfig(const char *name)
 const xstring& Torrent::Status()
 {
    if(metainfo_data)
-      return xstring::format("Getting meta-data: %s",metainfo_data->Status());
+      return xstring::format(_("Getting meta-data: %s"),metainfo_data->Status());
    if(validating) {
-      return xstring::format("Validation: %u/%u (%u%%) %s%s",validate_index,total_pieces,
+      return xstring::format(_("Validation: %u/%u (%u%%) %s%s"),validate_index,total_pieces,
 	 validate_index*100/total_pieces,recv_rate.GetStrS(),
-	 recv_rate.GetETAStrFromSize((total_pieces-validate_index-1)*piece_length+last_piece_length).get());
+	 recv_rate.GetETAStrFromSize((off_t)(total_pieces-validate_index-1)*piece_length+last_piece_length).get());
    }
    if(shutting_down) {
       if(trackers.count()==0)
@@ -1357,7 +1405,7 @@ const xstring& Torrent::Status()
       for(int i=0; i<trackers.count(); i++) {
 	 const char *status=trackers[i]->Status();
 	 if(status[0]) {
-	    xstring &s=xstring::get_tmp("Shutting down: ");
+	    xstring &s=xstring::get_tmp(_("Shutting down: "));
 	    if(trackers.count()>1)
 	       s.appendf("%d. ",i+1);
 	    s.append(status);
@@ -2014,9 +2062,9 @@ int TorrentPeer::Do()
       if(s!=UNPACK_SUCCESS) {
 	 if(s==UNPACK_PREMATURE_EOF) {
 	    if(recv_buf->Size()>0)
-	       LogError(2,"peer unexpectedly closed connection after %s",recv_buf->Dump());
+	       LogError(2,_("peer unexpectedly closed connection after %s"),recv_buf->Dump());
 	    else
-	       LogError(4,"peer closed connection");
+	       LogError(4,_("peer closed connection (before handshake)"));
 	 }
 	 Disconnect();
 	 return MOVED;
@@ -2089,7 +2137,7 @@ int TorrentPeer::Do()
    }
 
    if(recv_buf->Eof() && recv_buf->Size()==0) {
-      LogError(4,"peer closed connection");
+      LogError(4,_("peer closed connection"));
       Disconnect();
       return MOVED;
    }
@@ -2101,9 +2149,9 @@ int TorrentPeer::Do()
    if(st!=UNPACK_SUCCESS)
    {
       if(st==UNPACK_PREMATURE_EOF)
-	 LogError(2,"peer unexpectedly closed connection after %s",recv_buf->Dump());
+	 LogError(2,_("peer unexpectedly closed connection after %s"),recv_buf->Dump());
       else
-	 LogError(2,"invalid peer response format");
+	 LogError(2,_("invalid peer response format"));
       Disconnect();
       return MOVED;
    }
@@ -2227,11 +2275,11 @@ const char *TorrentPeer::GetName() const
 const char *TorrentPeer::Status()
 {
    if(sock==-1)
-      return "Not connected";
+      return _("Not connected");
    if(!connected)
-      return "Connecting...";
+      return _("Connecting...");
    if(!peer_id)
-      return "Handshaking...";
+      return _("Handshaking...");
    xstring &buf=xstring::format("dn:%llu %sup:%llu %s",
       peer_recv,peer_recv_rate.GetStrS(),peer_sent,peer_send_rate.GetStrS());
    if(peer_interested)
@@ -2466,7 +2514,7 @@ int TorrentListener::Do()
 	       TimeoutS(1);
 	       return m;
 	    }
-	    error=Error::Fatal("Cannot bind a socket for torrent:port-range");
+	    error=Error::Fatal(_("Cannot bind a socket for torrent:port-range"));
 	    return MOVED;
 	 }
 	 LogError(10,"bind(%s): %s",addr.to_string().get(),strerror(saved_errno));
@@ -2494,7 +2542,7 @@ int TorrentListener::Do()
       return m;
    }
    rate.Add(1);
-   LogNote(3,"Accepted connection from [%s]:%d",remote_addr.address(),remote_addr.port());
+   LogNote(3,_("Accepted connection from [%s]:%d"),remote_addr.address(),remote_addr.port());
    (void)new TorrentDispatcher(a,&remote_addr);
    m=MOVED;
 
@@ -2528,7 +2576,7 @@ int TorrentDispatcher::Do()
 {
    if(timeout_timer.Stopped())
    {
-      LogError(1,"peer handshake timeout");
+      LogError(1,_("peer handshake timeout"));
       deleting=true;
       return MOVED;
    }
@@ -2540,9 +2588,9 @@ int TorrentDispatcher::Do()
    if((unsigned)recv_buf->Size()<1+proto_len+8+SHA1_DIGEST_SIZE) {
       if(recv_buf->Eof()) {
 	 if(recv_buf->Size()>0)
-	    LogError(1,"peer short handshake");
+	    LogError(1,_("peer short handshake"));
 	 else
-	    LogError(4,"peer closed connection");
+	    LogError(4,_("peer closed just accepted connection"));
 	 deleting=true;
 	 return MOVED;
       }
@@ -2593,7 +2641,7 @@ int TorrentJob::Do()
    if(!completed && torrent->Complete()) {
       if(parent->WaitsFor(this)) {
 	 PrintStatus(1,"");
-	 printf("Seeding in background...\n");
+	 printf(_("Seeding in background...\n"));
 	 parent->RemoveWaiting(this);
       }
       completed=true;
@@ -2608,7 +2656,7 @@ const char *TorrentTracker::Status() const
       return "";
    if(t_session->IsOpen())
       return t_session->CurrentStatus();
-   return xstring::format("next request in %s",NextRequestIn());
+   return xstring::format(_("next request in %s"),NextRequestIn());
 }
 
 xstring& TorrentJob::FormatStatus(xstring& s,int v,const char *tab)
@@ -2619,6 +2667,7 @@ xstring& TorrentJob::FormatStatus(xstring& s,int v,const char *tab)
    s.appendf("%s%s\n",tab,torrent->Status().get());
    if(torrent->GetRatio()>0)
       s.appendf("%sratio: %f\n",tab,torrent->GetRatio());
+
    if(v>2) {
       s.appendf("%sinfo hash: %s\n",tab,torrent->GetInfoHash().dump());
       s.appendf("%stotal length: %llu\n",tab,torrent->TotalLength());
@@ -2638,12 +2687,14 @@ xstring& TorrentJob::FormatStatus(xstring& s,int v,const char *tab)
       }
    }
 
+   if(torrent->ShuttingDown())
+      return s;
+
    if(torrent->GetPeersCount()<=5 || v>1) {
       const TaskRefArray<TorrentPeer>& peers=torrent->GetPeers();
-      if(v<=2) {
-	 s.appendf("%s  not connected peers: %d\n",tab,
-	    torrent->GetPeersCount()-torrent->GetConnectedPeersCount());
-      }
+      int not_connected_peers=torrent->GetPeersCount()-torrent->GetConnectedPeersCount();
+      if(v<=2 && not_connected_peers>0)
+	 s.appendf("%s  not connected peers: %d\n",tab,not_connected_peers);
       for(int i=0; i<peers.count(); i++) {
 	 if(peers[i]->Connected() || v>2)
 	    s.appendf("%s  %s: %s\n",tab,peers[i]->GetName(),peers[i]->Status());
@@ -2682,6 +2733,8 @@ CDECL_END
 
 CMD(torrent)
 {
+   Torrent::ClassInit();
+
 #define args (parent->args)
 #define eprintf parent->eprintf
    enum {
@@ -2774,6 +2827,7 @@ CMD(torrent)
 #ifdef MODULE_CMD_TORRENT
 void module_init()
 {
+   Torrent::ClassInit();
    CmdExec::RegisterCommand("torrent",cmd_torrent);
 }
 #endif
