@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2007 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: mgetJob.cc,v 1.30 2009/10/09 14:46:57 lav Exp $ */
+/* $Id: mgetJob.cc,v 1.33 2011/04/29 04:58:29 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -42,23 +42,19 @@ void mgetJob::ShowRunStatus(const SMTaskRef<StatusLine>& s)
    }
    GetJob::ShowRunStatus(s);
 }
-void mgetJob::PrintStatus(int v,const char *prefix)
+xstring& mgetJob::FormatStatus(xstring& buf,int v,const char *prefix)
 {
    if(mkdir_job)
-   {
-      printf("\tCreating remote directories\n");
-      return;
-   }
+      return buf.append("\tCreating remote directories\n");
    if(rg)
    {
-      SessionJob::PrintStatus(v,prefix);
+      SessionJob::FormatStatus(buf,v,prefix);
       const char *s=rg->Status();
       if(!s || !s[0])
-	 return;
-      printf("\t%s\n",s);
-      return;
+	 return buf;
+      return buf.appendf("\t%s\n",s);
    }
-   GetJob::PrintStatus(v,prefix);
+   return GetJob::FormatStatus(buf,v,prefix);
 }
 
 mgetJob::mgetJob(FileAccess *session,ArgV *a,bool c,bool md)
@@ -125,7 +121,7 @@ void mgetJob::LocalGlob(const char *p)
       fprintf(stderr,_("%s: %s: no files found\n"),op,p);
       count++;
       errors++;
-      return;
+      goto leave;
    }
    for(i=0; i<(int)pglob.gl_pathc; i++)
    {
@@ -139,6 +135,7 @@ void mgetJob::LocalGlob(const char *p)
       make_directory(src);
       args->Append(output_file_name(src,0,!reverse,output_dir,make_dirs));
    }
+leave:
    globfree(&pglob);
 }
 
