@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: resource.cc,v 1.165 2010/04/29 11:00:44 lav Exp $ */
+/* $Id: resource.cc,v 1.171 2011/04/22 15:43:11 lav Exp $ */
 
 #include <config.h>
 
@@ -200,6 +200,7 @@ static ResType lftp_vars[] = {
    {"ftp:timezone",		 "GMT",   0,0},
    {"ftp:skey-allow",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:skey-force",		 "no",    ResMgr::BoolValidate,0},
+   {"ftp:netkey-allow",		 "yes",   ResMgr::BoolValidate,0},
 #if USE_SSL
    {"ftp:ssl-allow",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:ssl-force",		 "no",	  ResMgr::BoolValidate,0},
@@ -234,6 +235,7 @@ static ResType lftp_vars[] = {
    {"ftp:use-stat",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:use-stat-for-list",	 "no",	  ResMgr::BoolValidate,0},
    {"ftp:use-telnet-iac",	 "yes",   ResMgr::BoolValidate,0},
+   {"ftp:use-ip-tos",		 "no",	  ResMgr::BoolValidate,0},
    {"ftp:use-quit",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:verify-address",	 "no",    ResMgr::BoolValidate,0},
    {"ftp:verify-port",		 "no",    ResMgr::BoolValidate,0},
@@ -301,9 +303,10 @@ static ResType lftp_vars[] = {
    {"mirror:set-permissions",	 "yes",   ResMgr::BoolValidate,ResMgr::NoClosure},
    {"mirror:dereference",	 "no",    ResMgr::BoolValidate,ResMgr::NoClosure},
    {"mirror:skip-noaccess",	 "no",    ResMgr::BoolValidate,ResMgr::NoClosure},
+   {"mirror:no-empty-dirs",	 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
 
    {"sftp:max-packets-in-flight","16",	  ResMgr::UNumberValidate,0},
-   {"sftp:protocol-version",	 "4",	  ResMgr::UNumberValidate,0},
+   {"sftp:protocol-version",	 "6",	  ResMgr::UNumberValidate,0},
    {"sftp:size-read",		 "32k",	  ResMgr::UNumberValidate,0},
    {"sftp:size-write",		 "32k",	  ResMgr::UNumberValidate,0},
    {"sftp:connect-program",	 "ssh -a -x",0,0},
@@ -341,6 +344,7 @@ static ResType lftp_vars[] = {
    {"xfer:verify-command",	 "",	  ResMgr::FileExecutable,0},
    {"xfer:log",			 "yes",	  ResMgr::BoolValidate,ResMgr::NoClosure},
    {"xfer:auto-rename",		 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
+   {"xfer:log-file",              "",     ResMgr::FileCreatable,ResMgr::NoClosure},
 
 #if USE_SSL
    {"ssl:ca-file",		 "",	  ResMgr::FileReadable,ResMgr::NoClosure},
@@ -348,7 +352,7 @@ static ResType lftp_vars[] = {
    {"ssl:key-file",		 "",	  ResMgr::FileReadable,0},
    {"ssl:cert-file",		 "",	  ResMgr::FileReadable,0},
    {"ssl:check-hostname",	 "yes",	  ResMgr::BoolValidate,0},
-   {"ssl:verify-certificate",	 "no",	  ResMgr::BoolValidate,0},
+   {"ssl:verify-certificate",	 "yes",	  ResMgr::BoolValidate,0},
 # if USE_OPENSSL
    {"ssl:ca-path",		 "",	  ResMgr::DirReadable,ResMgr::NoClosure},
    {"ssl:crl-path",		 "",	  ResMgr::DirReadable,ResMgr::NoClosure},
